@@ -10,7 +10,7 @@ use Apache2::RequestUtil ();
 use Apache2::Const       -compile => qw( OK HTTP_UNAUTHORIZED );
 
 # ABSTRACT: Apache authentication handler for PlugAuth
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 
 sub handler
@@ -47,7 +47,7 @@ PlugAuth::Client::Tiny::Apache2AuthenHandler - Apache authentication handler for
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -63,8 +63,16 @@ In your httpd.conf:
 
 =head1 DESCRIPTION
 
-This module provides an PlugAuth authentication (via L<PlugAuth::Tiny>) for
-your legacy Apache2 application.
+This module provides PlugAuth authentication (via L<PlugAuth::Tiny>) for your legacy Apache2
+application.
+
+=head1 ENVIRONMENT
+
+=head2 PLUGAUTH_URL
+
+ PerlSetEnv PLUGAUTH_URL http://localhost:3001
+
+Specifies the URL for the PlugAuth server to authenticate against.
 
 =head1 SEE ALSO
 
